package com.company.demodnd.web.screens;

import com.company.demodnd.entity.CalendarEvent;
import com.haulmont.cuba.core.global.DataManager;
import com.haulmont.cuba.core.global.Metadata;
import com.haulmont.cuba.gui.Notifications;
import com.haulmont.cuba.gui.components.Calendar;
import com.haulmont.cuba.gui.components.Table;
import com.haulmont.cuba.gui.components.VBoxLayout;
import com.haulmont.cuba.gui.model.CollectionContainer;
import com.haulmont.cuba.gui.screen.*;
import com.haulmont.cuba.security.entity.User;
import com.haulmont.cuba.web.widgets.CubaTable;
import com.vaadin.event.dd.DragAndDropEvent;
import com.vaadin.event.dd.DropHandler;
import com.vaadin.event.dd.acceptcriteria.AcceptAll;
import com.vaadin.event.dd.acceptcriteria.AcceptCriterion;
import com.vaadin.ui.AbstractOrderedLayout;
import com.vaadin.ui.DragAndDropWrapper;

import javax.inject.Inject;
import java.util.Date;

@UiController("demodnd_DemoScreen")
@UiDescriptor("demo-screen.xml")
@LoadDataBeforeShow
public class DemoScreen extends Screen {

    @Inject
    private Table<User> usersTable;

    @Inject
    private VBoxLayout dndWrapper;

    @Inject
    private Calendar<Date> calendar;

    @Inject
    private Notifications notifications;

    @Inject
    private CollectionContainer<User> usersDc;

    @Inject
    private CollectionContainer<CalendarEvent> calendarEventDc;

    @Subscribe
    public void onInit(InitEvent event) {
        usersTable.withUnwrapped(CubaTable.class,
                table -> table.setDragMode(com.vaadin.v7.ui.Table.TableDragMode.ROW));

        dndWrapper.withUnwrapped(AbstractOrderedLayout.class, layout -> {
            DragAndDropWrapper wrapper = new DragAndDropWrapper(calendar.unwrap(com.vaadin.v7.ui.Calendar.class));
            wrapper.setWidth("100%");
            wrapper.setHeight("100%");
            wrapper.setDropHandler(new DropHandler() {
                @Override
                public void drop(DragAndDropEvent event) {
                    Object userId = event.getTransferable().getData("itemId");
                    User user = usersDc.getItem(userId);

                    // show input dialog or any other screen
                    notifications.create(Notifications.NotificationType.TRAY)
                            .withCaption("User: " + user.getLogin())
                            .show();
                }

                @Override
                public AcceptCriterion getAcceptCriterion() {
                    return AcceptAll.get();
                }
            });
            layout.addComponent(wrapper);
        });
    }
}